from skimage.transform import resize


def resize_image(img, proportion):
    assert 0 <= proportion <= 1, "Specify a valid proportion between 0 and 1."
    height = round(img.shape[0] * proportion)
    width = round(img.shape[1] * proportion)
    img_resized = resize(img, (height, width), anti_aliasing=True)
    return img_resized



import numpy as np
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity


def find_differemce(img1, img2):
    assert img1.shape == img2.shape, "Specify 2 images with same shape"
    gray_img1 = rgb2gray(img1)
    gray_img2 = rgb2gray(img2)
    (score, difference_img) = structural_similarity(gray_img1, gray_img2, full=True)
    print(f"Similarity of the images: {score}")
    normalized_difference_img = (difference_img - np.min(difference_img)) / (
            np.max(difference_img) - np.min(difference_img))
    return normalized_difference_img


def transfer_histogram(img1, img2):
    return match_histograms(img1, img2, multichannel=True)



import matplotlib.pyplot as plt


def plot_image(img):
    plt.figure(figsize=(12, 4))
    plt.imshow(img, cmap='gray')
    plt.axis('off')
    plt.show()


def plot_result(*args):
    number_images = len(args)
    fig, axis = plt.subplots(nrows=1, ncols=number_images, figsize=(12, 4))
    names_lst = ['image {}'.format(i) for i in range(1, number_images + 1)]
    names_lst.append('Result')

    for ax, name, img in zip(axis, names_lst, args):
        ax.set_title(name)
        ax.imshow(img, cmap='gray')
        ax.axis('off')
    fig.tight_layout()
    plt.show()


def plot_histogram(img):
    fig, axis = plt.subplots(nrows=1, ncols=3, figsize=(12, 4), sharex=True, sharey=True)
    color_lst = ['red', 'green', 'blue']
    for index, (ax, color) in enumerate(zip(axis, color_lst)):
        ax.set_title('{} histogram'.format(color.title()))
        ax.hist(img[:, :, index].ravel(), bins=256, color=color, alpha=0.8)
    fig.tight_layout()
    plt.show()



from setuptools import setup, find_packages

with open("README.md", 'r') as f:
    page_description = f.read()

with open('requirements.txt', 'r') as f:
    requirements = f.read().splitlines()

setup(
    name='iprcssngpy',
    version="0.0.1",
    author='Romário Pereira Marinho',
    author_email='eng.romariopmarinho@gmail.com',
    description="Package creation and image processing study",
    long_description=page_description,
    long_description_content_type="text/markdown; charset=UTF-8;",
    packages=find_packages(),
    install_requires=requirements,
    python_requires='>=3.10',
)
